summaryrefslogtreecommitdiff
path: root/jstests/sharding/query/sharded_lookup_execution.js
diff options
context:
space:
mode:
Diffstat (limited to 'jstests/sharding/query/sharded_lookup_execution.js')
-rw-r--r--jstests/sharding/query/sharded_lookup_execution.js8
1 files changed, 6 insertions, 2 deletions
diff --git a/jstests/sharding/query/sharded_lookup_execution.js b/jstests/sharding/query/sharded_lookup_execution.js
index 2cc8323a7c7..9c332539455 100644
--- a/jstests/sharding/query/sharded_lookup_execution.js
+++ b/jstests/sharding/query/sharded_lookup_execution.js
@@ -15,7 +15,7 @@ load("jstests/aggregation/extras/utils.js"); // For arrayEq.
load("jstests/libs/profiler.js"); // For profilerHas*OrThrow helper functions.
load("jstests/libs/log.js"); // For findMatchingLogLines.
-const st = new ShardingTest({shards: [{verbose: 3}, {verbose: 3}], mongos: 2});
+const st = new ShardingTest({shards: 2, mongos: 2});
const testName = "sharded_lookup";
const mongosDB = st.s0.getDB(testName);
@@ -24,9 +24,13 @@ const shardList = [st.shard0.getDB(testName), st.shard1.getDB(testName)];
assert.commandWorked(mongosDB.adminCommand({enableSharding: mongosDB.getName()}));
st.ensurePrimaryShard(mongosDB.getName(), st.shard0.shardName);
// Turn on the profiler for both shards.
assert.commandWorked(st.shard0.getDB(testName).setProfilingLevel(2));
assert.commandWorked(st.shard1.getDB(testName).setProfilingLevel(2));
+assert.commandWorked(
+ st.shard0.adminCommand({setParameter: 1, logComponentVerbosity: {query: {verbosity: 3}}}));
+assert.commandWorked(
+ st.shard1.adminCommand({setParameter: 1, logComponentVerbosity: {query: {verbosity: 3}}}));
const ordersColl = mongosDB.orders;
const reviewsColl = mongosDB.reviews;
@@ -24,9 +24,13 @@ const shardList = [st.shard0.getDB(testName), st.shard1.getDB(testName)];
assert.commandWorked(mongosDB.adminCommand({enableSharding: mongosDB.getName()}));
st.ensurePrimaryShard(mongosDB.getName(), st.shard0.shardName);
-// Turn on the profiler for both shards.
+// Turn on the profiler and increase the query log level for both shards.
assert.commandWorked(st.shard0.getDB(testName).setProfilingLevel(2));
assert.commandWorked(st.shard1.getDB(testName).setProfilingLevel(2));